From 0f7cfbf5c2b3403effc5910f57f420b58ed91330 Mon Sep 17 00:00:00 2001
From: Jim Meyering <meyering@fb.com>
Date: Sat, 4 Jan 2020 22:21:17 -0800
Subject: [PATCH] stdlib: avoid canonicalize_file_name contradiction

* lib/stdlib.in.h (canonicalize_file_name): Remove the nonnull
attribute from its declaration. tests/test-canonicalize-lgpl.c
passes null_ptr () to it, which (via this contradiction) would
provoke a segfault from GCC 10. See a small reproducer and
discussion in https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93156
---
 ChangeLog       | 9 +++++++++
 lib/stdlib.in.h | 6 ++----
 2 files changed, 11 insertions(+), 4 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 6d9ea9e52..730f53727 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,12 @@
+2020-01-04  Jim Meyering  <meyering@fb.com>
+
+	stdlib: avoid canonicalize_file_name contradiction
+	* lib/stdlib.in.h (canonicalize_file_name): Remove the nonnull
+	attribute from its declaration. tests/test-canonicalize-lgpl.c
+	passes null_ptr () to it, which (via this contradiction) would
+	provoke a segfault from GCC 10. See a small reproducer and
+	discussion in https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93156
+
 2020-01-04  Bruno Haible  <bruno@clisp.org>

 	mbsnrtoc32s: Add tests.
diff --git a/lib/stdlib.in.h b/lib/stdlib.in.h
index e088959b2..938ec37b1 100644
--- a/lib/stdlib.in.h
+++ b/lib/stdlib.in.h
@@ -191,13 +191,11 @@ _GL_WARN_ON_USE (calloc, "calloc is not POSIX compliant everywhere - "
 #  if !(defined __cplusplus && defined GNULIB_NAMESPACE)
 #   define canonicalize_file_name rpl_canonicalize_file_name
 #  endif
-_GL_FUNCDECL_RPL (canonicalize_file_name, char *, (const char *name)
-                                                  _GL_ARG_NONNULL ((1)));
+_GL_FUNCDECL_RPL (canonicalize_file_name, char *, (const char *name));
 _GL_CXXALIAS_RPL (canonicalize_file_name, char *, (const char *name));
 # else
 #  if !@HAVE_CANONICALIZE_FILE_NAME@
-_GL_FUNCDECL_SYS (canonicalize_file_name, char *, (const char *name)
-                                                  _GL_ARG_NONNULL ((1)));
+_GL_FUNCDECL_SYS (canonicalize_file_name, char *, (const char *name));
 #  endif
 _GL_CXXALIAS_SYS (canonicalize_file_name, char *, (const char *name));
 # endif
-- 
2.24.0.390.g083378cc35

